==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/webutil/src/com/caucho/xtpdoc/IndexItem.java <==
/*
 * Copyright (c) 1998-2000 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Emil Ong
 */

package com.caucho.xtpdoc;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;
import java.io.IOException;
import java.io.PrintWriter;

public class IndexItem implements ContentItem {
  private String _id;
  private String _link;
  private FormattedTextWithAnchors _text;
  private Document _document;

  public IndexItem(Document document)
  {
    _document = document;
  }

  public void setId(String id)
  {
    _id = id;
  }

  public void setH(String link)
  {
    _link = link;
  }

  public FormattedTextWithAnchors createD()
  {
    _text = new FormattedTextWithAnchors(_document);
    return _text;
  }

  public void writeHtml(XMLStreamWriter out)
    throws XMLStreamException
  {
    out.writeStartElement("dt");
    out.writeStartElement("a");
    out.writeAttribute("name", _link);
    out.writeCharacters(_id);
    out.writeEndElement(); // a
    out.writeEndElement(); // dt

    out.writeStartElement("dd");
    _text.writeHtml(out);
    out.writeEndElement(); // dd
  }

  public void writeLaTeX(PrintWriter out)
    throws IOException
  {
    // XXX
  }

  public void writeLaTeXEnclosed(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }

  public void writeLaTeXTop(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/webutil/src/com/caucho/xtpdoc/IndexItem.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Emil Ong
 */

package com.caucho.xtpdoc;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;
import java.io.IOException;
import java.io.PrintWriter;

import com.caucho.config.ConfigException;

public class IndexItem implements ContentItem {
  private String _id;
  private String _link;
  private FormattedTextWithAnchors _text;
  private Document _document;

  public IndexItem(Document document)
  {
    _document = document;
  }

  public void setId(String id)
  {
    _id = id;
  }

  public void setH(String link)
  {
    _link = link;
  }

  public FormattedTextWithAnchors createD()
  {
    _text = new FormattedTextWithAnchors(_document);
    return _text;
  }

  public void writeHtml(XMLStreamWriter out)
    throws XMLStreamException
  {
    out.writeCharacters("\n");
    out.writeStartElement("dt");
    out.writeStartElement("a");
    out.writeAttribute("href", _link);
    out.writeCharacters(_id);
    out.writeEndElement(); // a
    out.writeEndElement(); // dt

    out.writeStartElement("dd");
    _text.writeHtml(out);
    out.writeEndElement(); // dd
  }

  public void writeLaTeX(PrintWriter out)
    throws IOException
  {
    // XXX
  }

  public void writeLaTeXEnclosed(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }

  public void writeLaTeXTop(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }

  public void writeLaTeXVerbatim(PrintWriter out)
    throws IOException
  {
    throw new ConfigException("<ix> not allowed in a verbatim context");
  }

  @Override
  public void writeAsciiDoc(PrintWriter out)
    throws IOException
  {
  }
}
